@@ -1,8 +1,8 @@
 use crate::option::MangleOptions;
-use swc_common::{collections::AHashSet, DUMMY_SP};
+use swc_common::collections::AHashSet;
 use swc_ecma_ast::*;
 use swc_ecma_utils::{find_ids, ident::IdentLike, Id};
-use swc_ecma_visit::{noop_visit_type, Node, Visit, VisitWith};
+use swc_ecma_visit::{noop_visit_type, Visit, VisitWith};
 
 pub(super) fn idents_to_preserve<N>(options: MangleOptions, n: &N) -> AHashSet<Id>
 where
@@ -14,7 +14,7 @@ where
         should_preserve: false,
         in_top_level: false,
     };
-    n.visit_with(&Invalid { span: DUMMY_SP }, &mut v);
+    n.visit_with(&mut v);
     v.preserved
 }
 pub(super) struct Preserver {
@@ -27,19 +27,19 @@ pub(super) struct Preserver {
 impl Visit for Preserver {
     noop_visit_type!();
 
-    fn visit_catch_clause(&mut self, n: &CatchClause, _: &dyn Node) {
+    fn visit_catch_clause(&mut self, n: &CatchClause) {
         let old = self.should_preserve;
 
         if self.options.ie8 && !self.options.top_level {
             self.should_preserve = true;
-            n.param.visit_with(&Invalid { span: DUMMY_SP }, self);
+            n.param.visit_with(self);
         }
 
         self.should_preserve = old;
-        n.body.visit_with(&Invalid { span: DUMMY_SP }, self);
+        n.body.visit_with(self);
     }
 
-    fn visit_class_decl(&mut self, n: &ClassDecl, _: &dyn Node) {
+    fn visit_class_decl(&mut self, n: &ClassDecl) {
         n.visit_children_with(self);
 
         if (self.in_top_level && !self.options.top_level) || self.options.keep_class_names {
@@ -47,7 +47,7 @@ impl Visit for Preserver {
         }
     }
 
-    fn visit_export_decl(&mut self, n: &ExportDecl, _: &dyn Node) {
+    fn visit_export_decl(&mut self, n: &ExportDecl) {
         n.visit_children_with(self);
 
         match &n.decl {
@@ -65,7 +65,7 @@ impl Visit for Preserver {
         }
     }
 
-    fn visit_expr(&mut self, n: &Expr, _: &dyn Node) {
+    fn visit_expr(&mut self, n: &Expr) {
         n.visit_children_with(self);
 
         match n {
@@ -78,7 +78,7 @@ impl Visit for Preserver {
         }
     }
 
-    fn visit_fn_decl(&mut self, n: &FnDecl, _: &dyn Node) {
+    fn visit_fn_decl(&mut self, n: &FnDecl) {
         n.visit_children_with(self);
 
         if (self.in_top_level && !self.options.top_level) || self.options.keep_fn_names {
@@ -86,7 +86,7 @@ impl Visit for Preserver {
         }
     }
 
-    fn visit_fn_expr(&mut self, n: &FnExpr, _: &dyn Node) {
+    fn visit_fn_expr(&mut self, n: &FnExpr) {
         n.visit_children_with(self);
 
         if self.options.keep_fn_names {
@@ -96,21 +96,21 @@ impl Visit for Preserver {
         }
     }
 
-    fn visit_member_expr(&mut self, n: &MemberExpr, _: &dyn Node) {
-        n.obj.visit_with(n, self);
+    fn visit_member_expr(&mut self, n: &MemberExpr) {
+        n.obj.visit_with(self);
         if n.computed {
-            n.prop.visit_with(n, self);
+            n.prop.visit_with(self);
         }
     }
 
-    fn visit_module_items(&mut self, n: &[ModuleItem], _: &dyn Node) {
+    fn visit_module_items(&mut self, n: &[ModuleItem]) {
         for n in n {
             self.in_top_level = true;
-            n.visit_with(&Invalid { span: DUMMY_SP }, self);
+            n.visit_with(self);
         }
     }
 
-    fn visit_pat(&mut self, n: &Pat, _: &dyn Node) {
+    fn visit_pat(&mut self, n: &Pat) {
         n.visit_children_with(self);
 
         match n {
@@ -123,22 +123,22 @@ impl Visit for Preserver {
         }
     }
 
-    fn visit_stmts(&mut self, n: &[Stmt], _: &dyn Node) {
+    fn visit_stmts(&mut self, n: &[Stmt]) {
         let old_top_level = self.in_top_level;
         for n in n {
             self.in_top_level = false;
-            n.visit_with(&Invalid { span: DUMMY_SP }, self);
+            n.visit_with(self);
         }
         self.in_top_level = old_top_level;
     }
 
-    fn visit_var_declarator(&mut self, n: &VarDeclarator, _: &dyn Node) {
+    fn visit_var_declarator(&mut self, n: &VarDeclarator) {
         n.visit_children_with(self);
 
         if self.in_top_level && !self.options.top_level {
             let old = self.should_preserve;
             self.should_preserve = true;
-            n.name.visit_with(n, self);
+            n.name.visit_with(self);
             self.should_preserve = old;
             return;
         }
@@ -148,7 +148,7 @@ impl Visit for Preserver {
                 Some(Expr::Fn(..)) | Some(Expr::Arrow(..)) => {
                     let old = self.should_preserve;
                     self.should_preserve = true;
-                    n.name.visit_with(n, self);
+                    n.name.visit_with(self);
                     self.should_preserve = old;
                 }
                 _ => {}
